aboutsummaryrefslogtreecommitdiffstats
path: root/tests/new
diff options
context:
space:
mode:
authorjhugunin <jhugunin>2002-12-23 22:57:19 +0000
committerjhugunin <jhugunin>2002-12-23 22:57:19 +0000
commitcd120597a7fef187088a4d53cdd78450f0f233f7 (patch)
tree30ba478c6f0832132521c911527589122ad3af4e /tests/new
parent025e908673ceaa62c49c1570fa0264f483755029 (diff)
downloadaspectj-cd120597a7fef187088a4d53cdd78450f0f233f7.tar.gz
aspectj-cd120597a7fef187088a4d53cdd78450f0f233f7.zip
changed callee-side call join point test to use execution
Diffstat (limited to 'tests/new')
-rw-r--r--tests/new/runtime/AllRuntime.java9
1 files changed, 5 insertions, 4 deletions
diff --git a/tests/new/runtime/AllRuntime.java b/tests/new/runtime/AllRuntime.java
index 6d817699c..cc7face15 100644
--- a/tests/new/runtime/AllRuntime.java
+++ b/tests/new/runtime/AllRuntime.java
@@ -52,6 +52,7 @@ public class AllRuntime {
ok = me.catchThrows();
if (!ok) result++;
+
int temp = me.publicIntMethod(2);
if (temp != 12) result++;
@@ -213,13 +214,13 @@ aspect A {
/** unused - enable to throw exception from run() */
public boolean TargetClass.throwException;
- public void TargetClass.run() {
+ public void TargetClass.run() throws Exception {
if (throwException) throwsException();
}
//-------------------------------------- advice
- /** callee-side call join point */ // todo: not being invoked, though TargetClass.toString is???
- before() : call(public String toString())
+ /** was callee-side call join point, now is execution */ // todo: not being invoked, though TargetClass.toString is???
+ before() : execution(public String toString())
&& target(TargetClass) {
/* comment out test to avoid StackOverflow
test(thisJoinPoint, thisJoinPointStaticPart, this,
@@ -469,7 +470,7 @@ aspect A {
}
sb.append(path);
sb.append(":" + sl.getLine());
- sb.append(":" + sl.getColumn());
+ //sb.append(":" + sl.getColumn());
}
}